Crate p3_field_testing

Crate p3_field_testing 

Utilities for testing field implementations.

Re-exports

pub use bench_func::*;
pub use dft_testing::*;
pub use extension_testing::*;
pub use packedfield_testing::*;

Modules

bench_func
dft_testing
extension_testing
from_integer_tests
Macros for testing the implementations of converting integers into field elements.
packedfield_testing

Macros

generate_from_int_tests
generate_from_large_i_int_tests
generate_from_large_u_int_tests
generate_from_small_int_tests
generate_from_small_neg_int_tests
test_extension_field
test_field
test_field_dft
test_field_dft_consistency
test_field_dft_large
test_frobenius
test_packed_extension_field
test_packed_field
test_prime_field
test_prime_field_32
test_prime_field_64
test_ring_with_eq
test_two_adic_extension_field
test_two_adic_field

Functions

test_add_slice
test_binary_ops
test_div_2exp_u64
test_dot_product
test_ef_two_adic_generator_consistency
test_field_axioms_proptest
Test field axioms (inverse, division) with deterministic edge cases and 256 random non-zero (x, y, z) triplets via proptest.
test_field_json_serialization
Test JSON serialization and deserialization for a set of field values.
test_generator
Given a list of the factors of the multiplicative group of a field, check that the defined generator is actually a generator of that group.
test_into_bytes_32
test_into_bytes_64
test_into_stream
test_inverse
test_mul_2exp_u64
test_powers_collect
Tests the optimized implementation of powers.take(n).collect()
test_prime_field_32_json_deserialization_boundaries
Test JSON deserialization boundary behavior for 32-bit prime fields.
test_ring_axioms_proptest
Test ring axioms with 256 random (x, y, z) triplets via proptest.
test_ring_with_eq
test_sums
test_two_adic_generator_consistency
test_two_adic_point_collection